@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package OD::Prometheus::Metric;
-$OD::Prometheus::Metric::VERSION = '0.002';
+$OD::Prometheus::Metric::VERSION = '0.003';
 use v5.24;
 use Moose;
 use Data::Printer;
@@ -14,7 +14,7 @@ OD::Prometheus::Metric - Class representing a Prometheus metric
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =cut
 
@@ -166,7 +166,7 @@ sub parse {
 		if( exists $+{ labels } ) {
 			my @labelstrs = split(/\s*,\s*/,$+{ labels });
 			for my $labelstr ( @labelstrs ) {
-				say $labelstr;
+				#### say $labelstr;
 				if( $labelstr =~ /
 						^
 						(?<label_name>[a-zA-Z_][a-zA-Z0-9_]*) #capture $1
